=======
History
=======

0.1.1 (2020-04-04)
------------------

* Fixed dependencies not being automatically installed
* Updated classifiers and URLs for PyPI
* Added more tests and updated existing ones

0.1.0 (2020-04-03)
------------------

* First release on PyPI.
* Implemented support for most of the endpoints except recording and IPCam stuff
